@@ -616,15 +616,16 @@ void QgsLayoutElevationProfileWidget::copySettingsFromProfileCanvas( QgsElevatio
   mProfile->plot()->yAxis().setLabelInterval( canvas->plot().yAxis().labelInterval() );
 
   QList<QgsMapLayer *> canvasLayers = canvas->layers();
-  // canvas layers are in opposite direction to what the layout item requires
-  std::reverse( canvasLayers.begin(), canvasLayers.end() );
   mProfile->setLayers( canvasLayers );
   const QList<QgsLayerTreeLayer *> layers = mLayerTree->findLayers();
   for ( QgsLayerTreeLayer *layer : layers )
   {
     layer->setItemVisibilityChecked( mProfile->layers().contains( layer->layer() ) );
   }
-  mLayerTree->reorderGroupLayers( mProfile->layers() );
+
+  // canvas layers are in opposite direction to what the layer tree requires
+  std::reverse( canvasLayers.begin(), canvasLayers.end() );
+  mLayerTree->reorderGroupLayers( canvasLayers );
 
   mProfile->invalidateCache();
   mProfile->update();
@@ -707,12 +708,15 @@ void QgsLayoutElevationProfileWidget::setGuiElementValues()
   mSpinTopMargin->setValue( mProfile->plot()->margins().top() );
   mSpinBottomMargin->setValue( mProfile->plot()->margins().bottom() );
 
+  QList<QgsMapLayer *> profileLayers = mProfile->layers();
   const QList<QgsLayerTreeLayer *> layers = mLayerTree->findLayers();
   for ( QgsLayerTreeLayer *layer : layers )
   {
-    layer->setItemVisibilityChecked( mProfile->layers().contains( layer->layer() ) );
+    layer->setItemVisibilityChecked( profileLayers.contains( layer->layer() ) );
   }
-  mLayerTree->reorderGroupLayers( mProfile->layers() );
+  // elevation profile layers are in opposite direction to what the layer tree requires
+  std::reverse( profileLayers.begin(), profileLayers.end() );
+  mLayerTree->reorderGroupLayers( profileLayers );
 
   updateDataDefinedButton( mDDBtnTolerance );
   updateDataDefinedButton( mDDBtnMinDistance );
@@ -747,6 +751,8 @@ void QgsLayoutElevationProfileWidget::updateItemLayers()
       layers << layer;
   }
 
+  std::reverse( layers.begin(), layers.end() );
+
   mProfile->setLayers( layers );
   mProfile->update();
 }
